declare const service: {
    name: string;
    slug: string;
    description: string;
    host: string;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    headers: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    ttl: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            metadata: {
                exportDate: string;
            };
            headers: {
                'content-type': string;
            };
            limit?: undefined;
        };
        ttlNote: string;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields?: undefined;
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                name: import("zod").ZodString;
                metadata: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>;
                url: import("zod").ZodString;
                size_bytes: import("zod").ZodNumber;
                expires_at: import("zod").ZodNullable<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name?: undefined;
            metadata?: undefined;
            headers?: undefined;
            limit?: undefined;
        };
        ttlNote?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
        ttlNote?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodOptional<import("zod").ZodString>;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    limit: import("zod").ZodOptional<import("zod").ZodNumber>;
                    offset: import("zod").ZodOptional<import("zod").ZodNumber>;
                    sort: import("zod").ZodOptional<import("zod").ZodString>;
                    direction: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                success: import("zod").ZodBoolean;
                streams: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                    metadata: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>;
                    url: import("zod").ZodString;
                    size_bytes: import("zod").ZodNumber;
                    expires_at: import("zod").ZodNullable<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            limit: number;
            metadata?: undefined;
            headers?: undefined;
        };
        ttlNote?: undefined;
        exampleHeaders?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields?: undefined;
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleHeaders: {
            'Content-Type': string;
        };
        exampleBody: string;
        responseFields?: undefined;
        ttlNote?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields?: undefined;
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
        ttlNote?: undefined;
        exampleHeaders?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=stream.d.ts.map