declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                created_at: import("zod").ZodString;
                updated_at: import("zod").ZodString;
                deleted: import("zod").ZodBoolean;
                deleted_at: import("zod").ZodNullable<import("zod").ZodString>;
                deleted_by: import("zod").ZodNullable<import("zod").ZodString>;
                start_time: import("zod").ZodString;
                end_time: import("zod").ZodNullable<import("zod").ZodString>;
                duration: import("zod").ZodNullable<import("zod").ZodNumber>;
                org_id: import("zod").ZodString;
                project_id: import("zod").ZodString;
                deployment_id: import("zod").ZodString;
                agent_ids: import("zod").ZodArray<import("zod").ZodString>;
                trigger: import("zod").ZodString;
                env: import("zod").ZodString;
                devmode: import("zod").ZodBoolean;
                pending: import("zod").ZodBoolean;
                success: import("zod").ZodBoolean;
                error: import("zod").ZodNullable<import("zod").ZodString>;
                metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
                cpu_time: import("zod").ZodNullable<import("zod").ZodNumber>;
                llm_cost: import("zod").ZodNullable<import("zod").ZodNumber>;
                llm_prompt_token_count: import("zod").ZodNullable<import("zod").ZodNumber>;
                llm_completion_token_count: import("zod").ZodNullable<import("zod").ZodNumber>;
                total_cost: import("zod").ZodNullable<import("zod").ZodNumber>;
                method: import("zod").ZodNullable<import("zod").ZodString>;
                url: import("zod").ZodNullable<import("zod").ZodString>;
                route_id: import("zod").ZodNullable<import("zod").ZodString>;
                thread_id: import("zod").ZodNullable<import("zod").ZodString>;
                timeline: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodUnknown>>;
                user_data: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        sectionTitle?: undefined;
        ttlNote?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                session: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    deleted: import("zod").ZodBoolean;
                    deleted_at: import("zod").ZodNullable<import("zod").ZodString>;
                    deleted_by: import("zod").ZodNullable<import("zod").ZodString>;
                    start_time: import("zod").ZodString;
                    end_time: import("zod").ZodNullable<import("zod").ZodString>;
                    duration: import("zod").ZodNullable<import("zod").ZodNumber>;
                    org_id: import("zod").ZodString;
                    project_id: import("zod").ZodString;
                    deployment_id: import("zod").ZodString;
                    agent_ids: import("zod").ZodArray<import("zod").ZodString>;
                    trigger: import("zod").ZodString;
                    env: import("zod").ZodString;
                    devmode: import("zod").ZodBoolean;
                    pending: import("zod").ZodBoolean;
                    success: import("zod").ZodBoolean;
                    error: import("zod").ZodNullable<import("zod").ZodString>;
                    metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
                    cpu_time: import("zod").ZodNullable<import("zod").ZodNumber>;
                    llm_cost: import("zod").ZodNullable<import("zod").ZodNumber>;
                    llm_prompt_token_count: import("zod").ZodNullable<import("zod").ZodNumber>;
                    llm_completion_token_count: import("zod").ZodNullable<import("zod").ZodNumber>;
                    total_cost: import("zod").ZodNullable<import("zod").ZodNumber>;
                    method: import("zod").ZodNullable<import("zod").ZodString>;
                    url: import("zod").ZodNullable<import("zod").ZodString>;
                    route_id: import("zod").ZodNullable<import("zod").ZodString>;
                    thread_id: import("zod").ZodNullable<import("zod").ZodString>;
                    timeline: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodUnknown>>;
                    user_data: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                agents: import("zod").ZodArray<import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    identifier: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
                eval_runs: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                    eval_id: import("zod").ZodString;
                    pending: import("zod").ZodBoolean;
                    success: import("zod").ZodBoolean;
                    error: import("zod").ZodNullable<import("zod").ZodString>;
                    result: import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                }, import("zod/v4/core").$strip>>;
                route: import("zod").ZodNullable<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    method: import("zod").ZodString;
                    path: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        sectionTitle?: undefined;
        ttlNote?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                body: import("zod").ZodString;
                severity: import("zod").ZodString;
                timestamp: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        ttlNote: string;
    })[];
};
export default service;
//# sourceMappingURL=session.d.ts.map