import { StructuredError } from '@agentuity/core';

export const OrgResponseError = StructuredError('OrgResponseError');
export const OrgResourceResponseError = StructuredError('OrgResourceResponseError');
