declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                objects: import("zod").ZodArray<import("zod").ZodObject<{
                    bucket_name: import("zod").ZodString;
                    key: import("zod").ZodString;
                    size: import("zod").ZodNumber;
                    etag: import("zod").ZodOptional<import("zod").ZodString>;
                    content_type: import("zod").ZodOptional<import("zod").ZodString>;
                    last_modified: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
                prefix: import("zod").ZodString;
                limit: import("zod").ZodNumber;
                offset: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                deleted_count: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                presigned_url: import("zod").ZodString;
                expiry_seconds: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                bucket_name: import("zod").ZodString;
                object_count: import("zod").ZodNumber;
                total_size: import("zod").ZodNumber;
                last_event_at: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                summary: import("zod").ZodObject<{
                    total_object_count: import("zod").ZodNumber;
                    total_size: import("zod").ZodNumber;
                    estimated_monthly_cost: import("zod").ZodNumber;
                    cost_per_gb_month: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>;
                buckets: import("zod").ZodArray<import("zod").ZodObject<{
                    bucket_name: import("zod").ZodString;
                    object_count: import("zod").ZodNumber;
                    total_size: import("zod").ZodNumber;
                    last_event_at: import("zod").ZodOptional<import("zod").ZodString>;
                    estimated_monthly_cost: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>>;
                daily: import("zod").ZodArray<import("zod").ZodObject<{
                    date: import("zod").ZodString;
                    total_object_count: import("zod").ZodNumber;
                    total_size: import("zod").ZodNumber;
                    estimated_cost: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>>;
                days: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                bucket_name: import("zod").ZodString;
                storage_tier: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodEnum<{
                    STANDARD: "STANDARD";
                    INFREQUENT_ACCESS: "INFREQUENT_ACCESS";
                    ARCHIVE: "ARCHIVE";
                }>>>;
                ttl: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                public: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodBoolean>>;
                cache_control: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                cors: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                    allowed_origins: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    allowed_methods: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    allowed_headers: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    expose_headers: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    max_age_seconds: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                }, import("zod/v4/core").$strip>>>;
                additional_headers: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>;
                bucket_location: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    storage_tier: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodEnum<{
                        STANDARD: "STANDARD";
                        INFREQUENT_ACCESS: "INFREQUENT_ACCESS";
                        ARCHIVE: "ARCHIVE";
                    }>>>;
                    ttl: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                    public: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodBoolean>>;
                    cache_control: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    cors: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                        allowed_origins: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                        allowed_methods: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                        allowed_headers: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                        expose_headers: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                        max_age_seconds: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                    }, import("zod/v4/core").$strip>>>;
                    additional_headers: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                bucket_name: import("zod").ZodString;
                storage_tier: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodEnum<{
                    STANDARD: "STANDARD";
                    INFREQUENT_ACCESS: "INFREQUENT_ACCESS";
                    ARCHIVE: "ARCHIVE";
                }>>>;
                ttl: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                public: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodBoolean>>;
                cache_control: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                cors: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodObject<{
                    allowed_origins: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    allowed_methods: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    allowed_headers: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    expose_headers: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    max_age_seconds: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                }, import("zod/v4/core").$strip>>>;
                additional_headers: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>>;
                bucket_location: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            ttl: number;
            public: boolean;
            cache_control: string;
        };
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=storage.d.ts.map